# coding: utf-8

"""
    The Plane REST API

    The Plane REST API  Visit our quick start guide and full API documentation at [developers.plane.so](https://developers.plane.so/api-reference/introduction).

    The version of the API Spec: 0.0.1
    Contact: support@plane.so
    This class is auto generated.

    Do not edit the class manually.
"""  # noqa: E501


import json
import re  # noqa: F401
from aenum import Enum





class TimezoneEnum(str, Enum):
    """
    * `Africa/Abidjan` - Africa/Abidjan * `Africa/Accra` - Africa/Accra * `Africa/Addis_Ababa` - Africa/Addis_Ababa * `Africa/Algiers` - Africa/Algiers * `Africa/Asmara` - Africa/Asmara * `Africa/Bamako` - Africa/Bamako * `Africa/Bangui` - Africa/Bangui * `Africa/Banjul` - Africa/Banjul * `Africa/Bissau` - Africa/Bissau * `Africa/Blantyre` - Africa/Blantyre * `Africa/Brazzaville` - Africa/Brazzaville * `Africa/Bujumbura` - Africa/Bujumbura * `Africa/Cairo` - Africa/Cairo * `Africa/Casablanca` - Africa/Casablanca * `Africa/Ceuta` - Africa/Ceuta * `Africa/Conakry` - Africa/Conakry * `Africa/Dakar` - Africa/Dakar * `Africa/Dar_es_Salaam` - Africa/Dar_es_Salaam * `Africa/Djibouti` - Africa/Djibouti * `Africa/Douala` - Africa/Douala * `Africa/El_Aaiun` - Africa/El_Aaiun * `Africa/Freetown` - Africa/Freetown * `Africa/Gaborone` - Africa/Gaborone * `Africa/Harare` - Africa/Harare * `Africa/Johannesburg` - Africa/Johannesburg * `Africa/Juba` - Africa/Juba * `Africa/Kampala` - Africa/Kampala * `Africa/Khartoum` - Africa/Khartoum * `Africa/Kigali` - Africa/Kigali * `Africa/Kinshasa` - Africa/Kinshasa * `Africa/Lagos` - Africa/Lagos * `Africa/Libreville` - Africa/Libreville * `Africa/Lome` - Africa/Lome * `Africa/Luanda` - Africa/Luanda * `Africa/Lubumbashi` - Africa/Lubumbashi * `Africa/Lusaka` - Africa/Lusaka * `Africa/Malabo` - Africa/Malabo * `Africa/Maputo` - Africa/Maputo * `Africa/Maseru` - Africa/Maseru * `Africa/Mbabane` - Africa/Mbabane * `Africa/Mogadishu` - Africa/Mogadishu * `Africa/Monrovia` - Africa/Monrovia * `Africa/Nairobi` - Africa/Nairobi * `Africa/Ndjamena` - Africa/Ndjamena * `Africa/Niamey` - Africa/Niamey * `Africa/Nouakchott` - Africa/Nouakchott * `Africa/Ouagadougou` - Africa/Ouagadougou * `Africa/Porto-Novo` - Africa/Porto-Novo * `Africa/Sao_Tome` - Africa/Sao_Tome * `Africa/Tripoli` - Africa/Tripoli * `Africa/Tunis` - Africa/Tunis * `Africa/Windhoek` - Africa/Windhoek * `America/Adak` - America/Adak * `America/Anchorage` - America/Anchorage * `America/Anguilla` - America/Anguilla * `America/Antigua` - America/Antigua * `America/Araguaina` - America/Araguaina * `America/Argentina/Buenos_Aires` - America/Argentina/Buenos_Aires * `America/Argentina/Catamarca` - America/Argentina/Catamarca * `America/Argentina/Cordoba` - America/Argentina/Cordoba * `America/Argentina/Jujuy` - America/Argentina/Jujuy * `America/Argentina/La_Rioja` - America/Argentina/La_Rioja * `America/Argentina/Mendoza` - America/Argentina/Mendoza * `America/Argentina/Rio_Gallegos` - America/Argentina/Rio_Gallegos * `America/Argentina/Salta` - America/Argentina/Salta * `America/Argentina/San_Juan` - America/Argentina/San_Juan * `America/Argentina/San_Luis` - America/Argentina/San_Luis * `America/Argentina/Tucuman` - America/Argentina/Tucuman * `America/Argentina/Ushuaia` - America/Argentina/Ushuaia * `America/Aruba` - America/Aruba * `America/Asuncion` - America/Asuncion * `America/Atikokan` - America/Atikokan * `America/Bahia` - America/Bahia * `America/Bahia_Banderas` - America/Bahia_Banderas * `America/Barbados` - America/Barbados * `America/Belem` - America/Belem * `America/Belize` - America/Belize * `America/Blanc-Sablon` - America/Blanc-Sablon * `America/Boa_Vista` - America/Boa_Vista * `America/Bogota` - America/Bogota * `America/Boise` - America/Boise * `America/Cambridge_Bay` - America/Cambridge_Bay * `America/Campo_Grande` - America/Campo_Grande * `America/Cancun` - America/Cancun * `America/Caracas` - America/Caracas * `America/Cayenne` - America/Cayenne * `America/Cayman` - America/Cayman * `America/Chicago` - America/Chicago * `America/Chihuahua` - America/Chihuahua * `America/Ciudad_Juarez` - America/Ciudad_Juarez * `America/Costa_Rica` - America/Costa_Rica * `America/Creston` - America/Creston * `America/Cuiaba` - America/Cuiaba * `America/Curacao` - America/Curacao * `America/Danmarkshavn` - America/Danmarkshavn * `America/Dawson` - America/Dawson * `America/Dawson_Creek` - America/Dawson_Creek * `America/Denver` - America/Denver * `America/Detroit` - America/Detroit * `America/Dominica` - America/Dominica * `America/Edmonton` - America/Edmonton * `America/Eirunepe` - America/Eirunepe * `America/El_Salvador` - America/El_Salvador * `America/Fort_Nelson` - America/Fort_Nelson * `America/Fortaleza` - America/Fortaleza * `America/Glace_Bay` - America/Glace_Bay * `America/Goose_Bay` - America/Goose_Bay * `America/Grand_Turk` - America/Grand_Turk * `America/Grenada` - America/Grenada * `America/Guadeloupe` - America/Guadeloupe * `America/Guatemala` - America/Guatemala * `America/Guayaquil` - America/Guayaquil * `America/Guyana` - America/Guyana * `America/Halifax` - America/Halifax * `America/Havana` - America/Havana * `America/Hermosillo` - America/Hermosillo * `America/Indiana/Indianapolis` - America/Indiana/Indianapolis * `America/Indiana/Knox` - America/Indiana/Knox * `America/Indiana/Marengo` - America/Indiana/Marengo * `America/Indiana/Petersburg` - America/Indiana/Petersburg * `America/Indiana/Tell_City` - America/Indiana/Tell_City * `America/Indiana/Vevay` - America/Indiana/Vevay * `America/Indiana/Vincennes` - America/Indiana/Vincennes * `America/Indiana/Winamac` - America/Indiana/Winamac * `America/Inuvik` - America/Inuvik * `America/Iqaluit` - America/Iqaluit * `America/Jamaica` - America/Jamaica * `America/Juneau` - America/Juneau * `America/Kentucky/Louisville` - America/Kentucky/Louisville * `America/Kentucky/Monticello` - America/Kentucky/Monticello * `America/Kralendijk` - America/Kralendijk * `America/La_Paz` - America/La_Paz * `America/Lima` - America/Lima * `America/Los_Angeles` - America/Los_Angeles * `America/Lower_Princes` - America/Lower_Princes * `America/Maceio` - America/Maceio * `America/Managua` - America/Managua * `America/Manaus` - America/Manaus * `America/Marigot` - America/Marigot * `America/Martinique` - America/Martinique * `America/Matamoros` - America/Matamoros * `America/Mazatlan` - America/Mazatlan * `America/Menominee` - America/Menominee * `America/Merida` - America/Merida * `America/Metlakatla` - America/Metlakatla * `America/Mexico_City` - America/Mexico_City * `America/Miquelon` - America/Miquelon * `America/Moncton` - America/Moncton * `America/Monterrey` - America/Monterrey * `America/Montevideo` - America/Montevideo * `America/Montserrat` - America/Montserrat * `America/Nassau` - America/Nassau * `America/New_York` - America/New_York * `America/Nome` - America/Nome * `America/Noronha` - America/Noronha * `America/North_Dakota/Beulah` - America/North_Dakota/Beulah * `America/North_Dakota/Center` - America/North_Dakota/Center * `America/North_Dakota/New_Salem` - America/North_Dakota/New_Salem * `America/Nuuk` - America/Nuuk * `America/Ojinaga` - America/Ojinaga * `America/Panama` - America/Panama * `America/Paramaribo` - America/Paramaribo * `America/Phoenix` - America/Phoenix * `America/Port-au-Prince` - America/Port-au-Prince * `America/Port_of_Spain` - America/Port_of_Spain * `America/Porto_Velho` - America/Porto_Velho * `America/Puerto_Rico` - America/Puerto_Rico * `America/Punta_Arenas` - America/Punta_Arenas * `America/Rankin_Inlet` - America/Rankin_Inlet * `America/Recife` - America/Recife * `America/Regina` - America/Regina * `America/Resolute` - America/Resolute * `America/Rio_Branco` - America/Rio_Branco * `America/Santarem` - America/Santarem * `America/Santiago` - America/Santiago * `America/Santo_Domingo` - America/Santo_Domingo * `America/Sao_Paulo` - America/Sao_Paulo * `America/Scoresbysund` - America/Scoresbysund * `America/Sitka` - America/Sitka * `America/St_Barthelemy` - America/St_Barthelemy * `America/St_Johns` - America/St_Johns * `America/St_Kitts` - America/St_Kitts * `America/St_Lucia` - America/St_Lucia * `America/St_Thomas` - America/St_Thomas * `America/St_Vincent` - America/St_Vincent * `America/Swift_Current` - America/Swift_Current * `America/Tegucigalpa` - America/Tegucigalpa * `America/Thule` - America/Thule * `America/Tijuana` - America/Tijuana * `America/Toronto` - America/Toronto * `America/Tortola` - America/Tortola * `America/Vancouver` - America/Vancouver * `America/Whitehorse` - America/Whitehorse * `America/Winnipeg` - America/Winnipeg * `America/Yakutat` - America/Yakutat * `Antarctica/Casey` - Antarctica/Casey * `Antarctica/Davis` - Antarctica/Davis * `Antarctica/DumontDUrville` - Antarctica/DumontDUrville * `Antarctica/Macquarie` - Antarctica/Macquarie * `Antarctica/Mawson` - Antarctica/Mawson * `Antarctica/McMurdo` - Antarctica/McMurdo * `Antarctica/Palmer` - Antarctica/Palmer * `Antarctica/Rothera` - Antarctica/Rothera * `Antarctica/Syowa` - Antarctica/Syowa * `Antarctica/Troll` - Antarctica/Troll * `Antarctica/Vostok` - Antarctica/Vostok * `Arctic/Longyearbyen` - Arctic/Longyearbyen * `Asia/Aden` - Asia/Aden * `Asia/Almaty` - Asia/Almaty * `Asia/Amman` - Asia/Amman * `Asia/Anadyr` - Asia/Anadyr * `Asia/Aqtau` - Asia/Aqtau * `Asia/Aqtobe` - Asia/Aqtobe * `Asia/Ashgabat` - Asia/Ashgabat * `Asia/Atyrau` - Asia/Atyrau * `Asia/Baghdad` - Asia/Baghdad * `Asia/Bahrain` - Asia/Bahrain * `Asia/Baku` - Asia/Baku * `Asia/Bangkok` - Asia/Bangkok * `Asia/Barnaul` - Asia/Barnaul * `Asia/Beirut` - Asia/Beirut * `Asia/Bishkek` - Asia/Bishkek * `Asia/Brunei` - Asia/Brunei * `Asia/Chita` - Asia/Chita * `Asia/Choibalsan` - Asia/Choibalsan * `Asia/Colombo` - Asia/Colombo * `Asia/Damascus` - Asia/Damascus * `Asia/Dhaka` - Asia/Dhaka * `Asia/Dili` - Asia/Dili * `Asia/Dubai` - Asia/Dubai * `Asia/Dushanbe` - Asia/Dushanbe * `Asia/Famagusta` - Asia/Famagusta * `Asia/Gaza` - Asia/Gaza * `Asia/Hebron` - Asia/Hebron * `Asia/Ho_Chi_Minh` - Asia/Ho_Chi_Minh * `Asia/Hong_Kong` - Asia/Hong_Kong * `Asia/Hovd` - Asia/Hovd * `Asia/Irkutsk` - Asia/Irkutsk * `Asia/Jakarta` - Asia/Jakarta * `Asia/Jayapura` - Asia/Jayapura * `Asia/Jerusalem` - Asia/Jerusalem * `Asia/Kabul` - Asia/Kabul * `Asia/Kamchatka` - Asia/Kamchatka * `Asia/Karachi` - Asia/Karachi * `Asia/Kathmandu` - Asia/Kathmandu * `Asia/Khandyga` - Asia/Khandyga * `Asia/Kolkata` - Asia/Kolkata * `Asia/Krasnoyarsk` - Asia/Krasnoyarsk * `Asia/Kuala_Lumpur` - Asia/Kuala_Lumpur * `Asia/Kuching` - Asia/Kuching * `Asia/Kuwait` - Asia/Kuwait * `Asia/Macau` - Asia/Macau * `Asia/Magadan` - Asia/Magadan * `Asia/Makassar` - Asia/Makassar * `Asia/Manila` - Asia/Manila * `Asia/Muscat` - Asia/Muscat * `Asia/Nicosia` - Asia/Nicosia * `Asia/Novokuznetsk` - Asia/Novokuznetsk * `Asia/Novosibirsk` - Asia/Novosibirsk * `Asia/Omsk` - Asia/Omsk * `Asia/Oral` - Asia/Oral * `Asia/Phnom_Penh` - Asia/Phnom_Penh * `Asia/Pontianak` - Asia/Pontianak * `Asia/Pyongyang` - Asia/Pyongyang * `Asia/Qatar` - Asia/Qatar * `Asia/Qostanay` - Asia/Qostanay * `Asia/Qyzylorda` - Asia/Qyzylorda * `Asia/Riyadh` - Asia/Riyadh * `Asia/Sakhalin` - Asia/Sakhalin * `Asia/Samarkand` - Asia/Samarkand * `Asia/Seoul` - Asia/Seoul * `Asia/Shanghai` - Asia/Shanghai * `Asia/Singapore` - Asia/Singapore * `Asia/Srednekolymsk` - Asia/Srednekolymsk * `Asia/Taipei` - Asia/Taipei * `Asia/Tashkent` - Asia/Tashkent * `Asia/Tbilisi` - Asia/Tbilisi * `Asia/Tehran` - Asia/Tehran * `Asia/Thimphu` - Asia/Thimphu * `Asia/Tokyo` - Asia/Tokyo * `Asia/Tomsk` - Asia/Tomsk * `Asia/Ulaanbaatar` - Asia/Ulaanbaatar * `Asia/Urumqi` - Asia/Urumqi * `Asia/Ust-Nera` - Asia/Ust-Nera * `Asia/Vientiane` - Asia/Vientiane * `Asia/Vladivostok` - Asia/Vladivostok * `Asia/Yakutsk` - Asia/Yakutsk * `Asia/Yangon` - Asia/Yangon * `Asia/Yekaterinburg` - Asia/Yekaterinburg * `Asia/Yerevan` - Asia/Yerevan * `Atlantic/Azores` - Atlantic/Azores * `Atlantic/Bermuda` - Atlantic/Bermuda * `Atlantic/Canary` - Atlantic/Canary * `Atlantic/Cape_Verde` - Atlantic/Cape_Verde * `Atlantic/Faroe` - Atlantic/Faroe * `Atlantic/Madeira` - Atlantic/Madeira * `Atlantic/Reykjavik` - Atlantic/Reykjavik * `Atlantic/South_Georgia` - Atlantic/South_Georgia * `Atlantic/St_Helena` - Atlantic/St_Helena * `Atlantic/Stanley` - Atlantic/Stanley * `Australia/Adelaide` - Australia/Adelaide * `Australia/Brisbane` - Australia/Brisbane * `Australia/Broken_Hill` - Australia/Broken_Hill * `Australia/Darwin` - Australia/Darwin * `Australia/Eucla` - Australia/Eucla * `Australia/Hobart` - Australia/Hobart * `Australia/Lindeman` - Australia/Lindeman * `Australia/Lord_Howe` - Australia/Lord_Howe * `Australia/Melbourne` - Australia/Melbourne * `Australia/Perth` - Australia/Perth * `Australia/Sydney` - Australia/Sydney * `Canada/Atlantic` - Canada/Atlantic * `Canada/Central` - Canada/Central * `Canada/Eastern` - Canada/Eastern * `Canada/Mountain` - Canada/Mountain * `Canada/Newfoundland` - Canada/Newfoundland * `Canada/Pacific` - Canada/Pacific * `Europe/Amsterdam` - Europe/Amsterdam * `Europe/Andorra` - Europe/Andorra * `Europe/Astrakhan` - Europe/Astrakhan * `Europe/Athens` - Europe/Athens * `Europe/Belgrade` - Europe/Belgrade * `Europe/Berlin` - Europe/Berlin * `Europe/Bratislava` - Europe/Bratislava * `Europe/Brussels` - Europe/Brussels * `Europe/Bucharest` - Europe/Bucharest * `Europe/Budapest` - Europe/Budapest * `Europe/Busingen` - Europe/Busingen * `Europe/Chisinau` - Europe/Chisinau * `Europe/Copenhagen` - Europe/Copenhagen * `Europe/Dublin` - Europe/Dublin * `Europe/Gibraltar` - Europe/Gibraltar * `Europe/Guernsey` - Europe/Guernsey * `Europe/Helsinki` - Europe/Helsinki * `Europe/Isle_of_Man` - Europe/Isle_of_Man * `Europe/Istanbul` - Europe/Istanbul * `Europe/Jersey` - Europe/Jersey * `Europe/Kaliningrad` - Europe/Kaliningrad * `Europe/Kirov` - Europe/Kirov * `Europe/Kyiv` - Europe/Kyiv * `Europe/Lisbon` - Europe/Lisbon * `Europe/Ljubljana` - Europe/Ljubljana * `Europe/London` - Europe/London * `Europe/Luxembourg` - Europe/Luxembourg * `Europe/Madrid` - Europe/Madrid * `Europe/Malta` - Europe/Malta * `Europe/Mariehamn` - Europe/Mariehamn * `Europe/Minsk` - Europe/Minsk * `Europe/Monaco` - Europe/Monaco * `Europe/Moscow` - Europe/Moscow * `Europe/Oslo` - Europe/Oslo * `Europe/Paris` - Europe/Paris * `Europe/Podgorica` - Europe/Podgorica * `Europe/Prague` - Europe/Prague * `Europe/Riga` - Europe/Riga * `Europe/Rome` - Europe/Rome * `Europe/Samara` - Europe/Samara * `Europe/San_Marino` - Europe/San_Marino * `Europe/Sarajevo` - Europe/Sarajevo * `Europe/Saratov` - Europe/Saratov * `Europe/Simferopol` - Europe/Simferopol * `Europe/Skopje` - Europe/Skopje * `Europe/Sofia` - Europe/Sofia * `Europe/Stockholm` - Europe/Stockholm * `Europe/Tallinn` - Europe/Tallinn * `Europe/Tirane` - Europe/Tirane * `Europe/Ulyanovsk` - Europe/Ulyanovsk * `Europe/Vaduz` - Europe/Vaduz * `Europe/Vatican` - Europe/Vatican * `Europe/Vienna` - Europe/Vienna * `Europe/Vilnius` - Europe/Vilnius * `Europe/Volgograd` - Europe/Volgograd * `Europe/Warsaw` - Europe/Warsaw * `Europe/Zagreb` - Europe/Zagreb * `Europe/Zurich` - Europe/Zurich * `GMT` - GMT * `Indian/Antananarivo` - Indian/Antananarivo * `Indian/Chagos` - Indian/Chagos * `Indian/Christmas` - Indian/Christmas * `Indian/Cocos` - Indian/Cocos * `Indian/Comoro` - Indian/Comoro * `Indian/Kerguelen` - Indian/Kerguelen * `Indian/Mahe` - Indian/Mahe * `Indian/Maldives` - Indian/Maldives * `Indian/Mauritius` - Indian/Mauritius * `Indian/Mayotte` - Indian/Mayotte * `Indian/Reunion` - Indian/Reunion * `Pacific/Apia` - Pacific/Apia * `Pacific/Auckland` - Pacific/Auckland * `Pacific/Bougainville` - Pacific/Bougainville * `Pacific/Chatham` - Pacific/Chatham * `Pacific/Chuuk` - Pacific/Chuuk * `Pacific/Easter` - Pacific/Easter * `Pacific/Efate` - Pacific/Efate * `Pacific/Fakaofo` - Pacific/Fakaofo * `Pacific/Fiji` - Pacific/Fiji * `Pacific/Funafuti` - Pacific/Funafuti * `Pacific/Galapagos` - Pacific/Galapagos * `Pacific/Gambier` - Pacific/Gambier * `Pacific/Guadalcanal` - Pacific/Guadalcanal * `Pacific/Guam` - Pacific/Guam * `Pacific/Honolulu` - Pacific/Honolulu * `Pacific/Kanton` - Pacific/Kanton * `Pacific/Kiritimati` - Pacific/Kiritimati * `Pacific/Kosrae` - Pacific/Kosrae * `Pacific/Kwajalein` - Pacific/Kwajalein * `Pacific/Majuro` - Pacific/Majuro * `Pacific/Marquesas` - Pacific/Marquesas * `Pacific/Midway` - Pacific/Midway * `Pacific/Nauru` - Pacific/Nauru * `Pacific/Niue` - Pacific/Niue * `Pacific/Norfolk` - Pacific/Norfolk * `Pacific/Noumea` - Pacific/Noumea * `Pacific/Pago_Pago` - Pacific/Pago_Pago * `Pacific/Palau` - Pacific/Palau * `Pacific/Pitcairn` - Pacific/Pitcairn * `Pacific/Pohnpei` - Pacific/Pohnpei * `Pacific/Port_Moresby` - Pacific/Port_Moresby * `Pacific/Rarotonga` - Pacific/Rarotonga * `Pacific/Saipan` - Pacific/Saipan * `Pacific/Tahiti` - Pacific/Tahiti * `Pacific/Tarawa` - Pacific/Tarawa * `Pacific/Tongatapu` - Pacific/Tongatapu * `Pacific/Wake` - Pacific/Wake * `Pacific/Wallis` - Pacific/Wallis * `US/Alaska` - US/Alaska * `US/Arizona` - US/Arizona * `US/Central` - US/Central * `US/Eastern` - US/Eastern * `US/Hawaii` - US/Hawaii * `US/Mountain` - US/Mountain * `US/Pacific` - US/Pacific * `UTC` - UTC
    """

    """
    allowed enum values
    """
    AFRICA_SLASH_ABIDJAN = 'Africa/Abidjan'
    AFRICA_SLASH_ACCRA = 'Africa/Accra'
    AFRICA_SLASH_ADDIS_ABABA = 'Africa/Addis_Ababa'
    AFRICA_SLASH_ALGIERS = 'Africa/Algiers'
    AFRICA_SLASH_ASMARA = 'Africa/Asmara'
    AFRICA_SLASH_BAMAKO = 'Africa/Bamako'
    AFRICA_SLASH_BANGUI = 'Africa/Bangui'
    AFRICA_SLASH_BANJUL = 'Africa/Banjul'
    AFRICA_SLASH_BISSAU = 'Africa/Bissau'
    AFRICA_SLASH_BLANTYRE = 'Africa/Blantyre'
    AFRICA_SLASH_BRAZZAVILLE = 'Africa/Brazzaville'
    AFRICA_SLASH_BUJUMBURA = 'Africa/Bujumbura'
    AFRICA_SLASH_CAIRO = 'Africa/Cairo'
    AFRICA_SLASH_CASABLANCA = 'Africa/Casablanca'
    AFRICA_SLASH_CEUTA = 'Africa/Ceuta'
    AFRICA_SLASH_CONAKRY = 'Africa/Conakry'
    AFRICA_SLASH_DAKAR = 'Africa/Dakar'
    AFRICA_SLASH_DAR_ES_SALAAM = 'Africa/Dar_es_Salaam'
    AFRICA_SLASH_DJIBOUTI = 'Africa/Djibouti'
    AFRICA_SLASH_DOUALA = 'Africa/Douala'
    AFRICA_SLASH_EL_AAIUN = 'Africa/El_Aaiun'
    AFRICA_SLASH_FREETOWN = 'Africa/Freetown'
    AFRICA_SLASH_GABORONE = 'Africa/Gaborone'
    AFRICA_SLASH_HARARE = 'Africa/Harare'
    AFRICA_SLASH_JOHANNESBURG = 'Africa/Johannesburg'
    AFRICA_SLASH_JUBA = 'Africa/Juba'
    AFRICA_SLASH_KAMPALA = 'Africa/Kampala'
    AFRICA_SLASH_KHARTOUM = 'Africa/Khartoum'
    AFRICA_SLASH_KIGALI = 'Africa/Kigali'
    AFRICA_SLASH_KINSHASA = 'Africa/Kinshasa'
    AFRICA_SLASH_LAGOS = 'Africa/Lagos'
    AFRICA_SLASH_LIBREVILLE = 'Africa/Libreville'
    AFRICA_SLASH_LOME = 'Africa/Lome'
    AFRICA_SLASH_LUANDA = 'Africa/Luanda'
    AFRICA_SLASH_LUBUMBASHI = 'Africa/Lubumbashi'
    AFRICA_SLASH_LUSAKA = 'Africa/Lusaka'
    AFRICA_SLASH_MALABO = 'Africa/Malabo'
    AFRICA_SLASH_MAPUTO = 'Africa/Maputo'
    AFRICA_SLASH_MASERU = 'Africa/Maseru'
    AFRICA_SLASH_MBABANE = 'Africa/Mbabane'
    AFRICA_SLASH_MOGADISHU = 'Africa/Mogadishu'
    AFRICA_SLASH_MONROVIA = 'Africa/Monrovia'
    AFRICA_SLASH_NAIROBI = 'Africa/Nairobi'
    AFRICA_SLASH_NDJAMENA = 'Africa/Ndjamena'
    AFRICA_SLASH_NIAMEY = 'Africa/Niamey'
    AFRICA_SLASH_NOUAKCHOTT = 'Africa/Nouakchott'
    AFRICA_SLASH_OUAGADOUGOU = 'Africa/Ouagadougou'
    AFRICA_SLASH_PORTO_MINUS_NOVO = 'Africa/Porto-Novo'
    AFRICA_SLASH_SAO_TOME = 'Africa/Sao_Tome'
    AFRICA_SLASH_TRIPOLI = 'Africa/Tripoli'
    AFRICA_SLASH_TUNIS = 'Africa/Tunis'
    AFRICA_SLASH_WINDHOEK = 'Africa/Windhoek'
    AMERICA_SLASH_ADAK = 'America/Adak'
    AMERICA_SLASH_ANCHORAGE = 'America/Anchorage'
    AMERICA_SLASH_ANGUILLA = 'America/Anguilla'
    AMERICA_SLASH_ANTIGUA = 'America/Antigua'
    AMERICA_SLASH_ARAGUAINA = 'America/Araguaina'
    AMERICA_SLASH_ARGENTINA_SLASH_BUENOS_AIRES = 'America/Argentina/Buenos_Aires'
    AMERICA_SLASH_ARGENTINA_SLASH_CATAMARCA = 'America/Argentina/Catamarca'
    AMERICA_SLASH_ARGENTINA_SLASH_CORDOBA = 'America/Argentina/Cordoba'
    AMERICA_SLASH_ARGENTINA_SLASH_JUJUY = 'America/Argentina/Jujuy'
    AMERICA_SLASH_ARGENTINA_SLASH_LA_RIOJA = 'America/Argentina/La_Rioja'
    AMERICA_SLASH_ARGENTINA_SLASH_MENDOZA = 'America/Argentina/Mendoza'
    AMERICA_SLASH_ARGENTINA_SLASH_RIO_GALLEGOS = 'America/Argentina/Rio_Gallegos'
    AMERICA_SLASH_ARGENTINA_SLASH_SALTA = 'America/Argentina/Salta'
    AMERICA_SLASH_ARGENTINA_SLASH_SAN_JUAN = 'America/Argentina/San_Juan'
    AMERICA_SLASH_ARGENTINA_SLASH_SAN_LUIS = 'America/Argentina/San_Luis'
    AMERICA_SLASH_ARGENTINA_SLASH_TUCUMAN = 'America/Argentina/Tucuman'
    AMERICA_SLASH_ARGENTINA_SLASH_USHUAIA = 'America/Argentina/Ushuaia'
    AMERICA_SLASH_ARUBA = 'America/Aruba'
    AMERICA_SLASH_ASUNCION = 'America/Asuncion'
    AMERICA_SLASH_ATIKOKAN = 'America/Atikokan'
    AMERICA_SLASH_BAHIA = 'America/Bahia'
    AMERICA_SLASH_BAHIA_BANDERAS = 'America/Bahia_Banderas'
    AMERICA_SLASH_BARBADOS = 'America/Barbados'
    AMERICA_SLASH_BELEM = 'America/Belem'
    AMERICA_SLASH_BELIZE = 'America/Belize'
    AMERICA_SLASH_BLANC_MINUS_SABLON = 'America/Blanc-Sablon'
    AMERICA_SLASH_BOA_VISTA = 'America/Boa_Vista'
    AMERICA_SLASH_BOGOTA = 'America/Bogota'
    AMERICA_SLASH_BOISE = 'America/Boise'
    AMERICA_SLASH_CAMBRIDGE_BAY = 'America/Cambridge_Bay'
    AMERICA_SLASH_CAMPO_GRANDE = 'America/Campo_Grande'
    AMERICA_SLASH_CANCUN = 'America/Cancun'
    AMERICA_SLASH_CARACAS = 'America/Caracas'
    AMERICA_SLASH_CAYENNE = 'America/Cayenne'
    AMERICA_SLASH_CAYMAN = 'America/Cayman'
    AMERICA_SLASH_CHICAGO = 'America/Chicago'
    AMERICA_SLASH_CHIHUAHUA = 'America/Chihuahua'
    AMERICA_SLASH_CIUDAD_JUAREZ = 'America/Ciudad_Juarez'
    AMERICA_SLASH_COSTA_RICA = 'America/Costa_Rica'
    AMERICA_SLASH_CRESTON = 'America/Creston'
    AMERICA_SLASH_CUIABA = 'America/Cuiaba'
    AMERICA_SLASH_CURACAO = 'America/Curacao'
    AMERICA_SLASH_DANMARKSHAVN = 'America/Danmarkshavn'
    AMERICA_SLASH_DAWSON = 'America/Dawson'
    AMERICA_SLASH_DAWSON_CREEK = 'America/Dawson_Creek'
    AMERICA_SLASH_DENVER = 'America/Denver'
    AMERICA_SLASH_DETROIT = 'America/Detroit'
    AMERICA_SLASH_DOMINICA = 'America/Dominica'
    AMERICA_SLASH_EDMONTON = 'America/Edmonton'
    AMERICA_SLASH_EIRUNEPE = 'America/Eirunepe'
    AMERICA_SLASH_EL_SALVADOR = 'America/El_Salvador'
    AMERICA_SLASH_FORT_NELSON = 'America/Fort_Nelson'
    AMERICA_SLASH_FORTALEZA = 'America/Fortaleza'
    AMERICA_SLASH_GLACE_BAY = 'America/Glace_Bay'
    AMERICA_SLASH_GOOSE_BAY = 'America/Goose_Bay'
    AMERICA_SLASH_GRAND_TURK = 'America/Grand_Turk'
    AMERICA_SLASH_GRENADA = 'America/Grenada'
    AMERICA_SLASH_GUADELOUPE = 'America/Guadeloupe'
    AMERICA_SLASH_GUATEMALA = 'America/Guatemala'
    AMERICA_SLASH_GUAYAQUIL = 'America/Guayaquil'
    AMERICA_SLASH_GUYANA = 'America/Guyana'
    AMERICA_SLASH_HALIFAX = 'America/Halifax'
    AMERICA_SLASH_HAVANA = 'America/Havana'
    AMERICA_SLASH_HERMOSILLO = 'America/Hermosillo'
    AMERICA_SLASH_INDIANA_SLASH_INDIANAPOLIS = 'America/Indiana/Indianapolis'
    AMERICA_SLASH_INDIANA_SLASH_KNOX = 'America/Indiana/Knox'
    AMERICA_SLASH_INDIANA_SLASH_MARENGO = 'America/Indiana/Marengo'
    AMERICA_SLASH_INDIANA_SLASH_PETERSBURG = 'America/Indiana/Petersburg'
    AMERICA_SLASH_INDIANA_SLASH_TELL_CITY = 'America/Indiana/Tell_City'
    AMERICA_SLASH_INDIANA_SLASH_VEVAY = 'America/Indiana/Vevay'
    AMERICA_SLASH_INDIANA_SLASH_VINCENNES = 'America/Indiana/Vincennes'
    AMERICA_SLASH_INDIANA_SLASH_WINAMAC = 'America/Indiana/Winamac'
    AMERICA_SLASH_INUVIK = 'America/Inuvik'
    AMERICA_SLASH_IQALUIT = 'America/Iqaluit'
    AMERICA_SLASH_JAMAICA = 'America/Jamaica'
    AMERICA_SLASH_JUNEAU = 'America/Juneau'
    AMERICA_SLASH_KENTUCKY_SLASH_LOUISVILLE = 'America/Kentucky/Louisville'
    AMERICA_SLASH_KENTUCKY_SLASH_MONTICELLO = 'America/Kentucky/Monticello'
    AMERICA_SLASH_KRALENDIJK = 'America/Kralendijk'
    AMERICA_SLASH_LA_PAZ = 'America/La_Paz'
    AMERICA_SLASH_LIMA = 'America/Lima'
    AMERICA_SLASH_LOS_ANGELES = 'America/Los_Angeles'
    AMERICA_SLASH_LOWER_PRINCES = 'America/Lower_Princes'
    AMERICA_SLASH_MACEIO = 'America/Maceio'
    AMERICA_SLASH_MANAGUA = 'America/Managua'
    AMERICA_SLASH_MANAUS = 'America/Manaus'
    AMERICA_SLASH_MARIGOT = 'America/Marigot'
    AMERICA_SLASH_MARTINIQUE = 'America/Martinique'
    AMERICA_SLASH_MATAMOROS = 'America/Matamoros'
    AMERICA_SLASH_MAZATLAN = 'America/Mazatlan'
    AMERICA_SLASH_MENOMINEE = 'America/Menominee'
    AMERICA_SLASH_MERIDA = 'America/Merida'
    AMERICA_SLASH_METLAKATLA = 'America/Metlakatla'
    AMERICA_SLASH_MEXICO_CITY = 'America/Mexico_City'
    AMERICA_SLASH_MIQUELON = 'America/Miquelon'
    AMERICA_SLASH_MONCTON = 'America/Moncton'
    AMERICA_SLASH_MONTERREY = 'America/Monterrey'
    AMERICA_SLASH_MONTEVIDEO = 'America/Montevideo'
    AMERICA_SLASH_MONTSERRAT = 'America/Montserrat'
    AMERICA_SLASH_NASSAU = 'America/Nassau'
    AMERICA_SLASH_NEW_YORK = 'America/New_York'
    AMERICA_SLASH_NOME = 'America/Nome'
    AMERICA_SLASH_NORONHA = 'America/Noronha'
    AMERICA_SLASH_NORTH_DAKOTA_SLASH_BEULAH = 'America/North_Dakota/Beulah'
    AMERICA_SLASH_NORTH_DAKOTA_SLASH_CENTER = 'America/North_Dakota/Center'
    AMERICA_SLASH_NORTH_DAKOTA_SLASH_NEW_SALEM = 'America/North_Dakota/New_Salem'
    AMERICA_SLASH_NUUK = 'America/Nuuk'
    AMERICA_SLASH_OJINAGA = 'America/Ojinaga'
    AMERICA_SLASH_PANAMA = 'America/Panama'
    AMERICA_SLASH_PARAMARIBO = 'America/Paramaribo'
    AMERICA_SLASH_PHOENIX = 'America/Phoenix'
    AMERICA_SLASH_PORT_MINUS_AU_MINUS_PRINCE = 'America/Port-au-Prince'
    AMERICA_SLASH_PORT_OF_SPAIN = 'America/Port_of_Spain'
    AMERICA_SLASH_PORTO_VELHO = 'America/Porto_Velho'
    AMERICA_SLASH_PUERTO_RICO = 'America/Puerto_Rico'
    AMERICA_SLASH_PUNTA_ARENAS = 'America/Punta_Arenas'
    AMERICA_SLASH_RANKIN_INLET = 'America/Rankin_Inlet'
    AMERICA_SLASH_RECIFE = 'America/Recife'
    AMERICA_SLASH_REGINA = 'America/Regina'
    AMERICA_SLASH_RESOLUTE = 'America/Resolute'
    AMERICA_SLASH_RIO_BRANCO = 'America/Rio_Branco'
    AMERICA_SLASH_SANTAREM = 'America/Santarem'
    AMERICA_SLASH_SANTIAGO = 'America/Santiago'
    AMERICA_SLASH_SANTO_DOMINGO = 'America/Santo_Domingo'
    AMERICA_SLASH_SAO_PAULO = 'America/Sao_Paulo'
    AMERICA_SLASH_SCORESBYSUND = 'America/Scoresbysund'
    AMERICA_SLASH_SITKA = 'America/Sitka'
    AMERICA_SLASH_ST_BARTHELEMY = 'America/St_Barthelemy'
    AMERICA_SLASH_ST_JOHNS = 'America/St_Johns'
    AMERICA_SLASH_ST_KITTS = 'America/St_Kitts'
    AMERICA_SLASH_ST_LUCIA = 'America/St_Lucia'
    AMERICA_SLASH_ST_THOMAS = 'America/St_Thomas'
    AMERICA_SLASH_ST_VINCENT = 'America/St_Vincent'
    AMERICA_SLASH_SWIFT_CURRENT = 'America/Swift_Current'
    AMERICA_SLASH_TEGUCIGALPA = 'America/Tegucigalpa'
    AMERICA_SLASH_THULE = 'America/Thule'
    AMERICA_SLASH_TIJUANA = 'America/Tijuana'
    AMERICA_SLASH_TORONTO = 'America/Toronto'
    AMERICA_SLASH_TORTOLA = 'America/Tortola'
    AMERICA_SLASH_VANCOUVER = 'America/Vancouver'
    AMERICA_SLASH_WHITEHORSE = 'America/Whitehorse'
    AMERICA_SLASH_WINNIPEG = 'America/Winnipeg'
    AMERICA_SLASH_YAKUTAT = 'America/Yakutat'
    ANTARCTICA_SLASH_CASEY = 'Antarctica/Casey'
    ANTARCTICA_SLASH_DAVIS = 'Antarctica/Davis'
    ANTARCTICA_SLASH_DUMONT_D_URVILLE = 'Antarctica/DumontDUrville'
    ANTARCTICA_SLASH_MACQUARIE = 'Antarctica/Macquarie'
    ANTARCTICA_SLASH_MAWSON = 'Antarctica/Mawson'
    ANTARCTICA_SLASH_MC_MURDO = 'Antarctica/McMurdo'
    ANTARCTICA_SLASH_PALMER = 'Antarctica/Palmer'
    ANTARCTICA_SLASH_ROTHERA = 'Antarctica/Rothera'
    ANTARCTICA_SLASH_SYOWA = 'Antarctica/Syowa'
    ANTARCTICA_SLASH_TROLL = 'Antarctica/Troll'
    ANTARCTICA_SLASH_VOSTOK = 'Antarctica/Vostok'
    ARCTIC_SLASH_LONGYEARBYEN = 'Arctic/Longyearbyen'
    ASIA_SLASH_ADEN = 'Asia/Aden'
    ASIA_SLASH_ALMATY = 'Asia/Almaty'
    ASIA_SLASH_AMMAN = 'Asia/Amman'
    ASIA_SLASH_ANADYR = 'Asia/Anadyr'
    ASIA_SLASH_AQTAU = 'Asia/Aqtau'
    ASIA_SLASH_AQTOBE = 'Asia/Aqtobe'
    ASIA_SLASH_ASHGABAT = 'Asia/Ashgabat'
    ASIA_SLASH_ATYRAU = 'Asia/Atyrau'
    ASIA_SLASH_BAGHDAD = 'Asia/Baghdad'
    ASIA_SLASH_BAHRAIN = 'Asia/Bahrain'
    ASIA_SLASH_BAKU = 'Asia/Baku'
    ASIA_SLASH_BANGKOK = 'Asia/Bangkok'
    ASIA_SLASH_BARNAUL = 'Asia/Barnaul'
    ASIA_SLASH_BEIRUT = 'Asia/Beirut'
    ASIA_SLASH_BISHKEK = 'Asia/Bishkek'
    ASIA_SLASH_BRUNEI = 'Asia/Brunei'
    ASIA_SLASH_CHITA = 'Asia/Chita'
    ASIA_SLASH_CHOIBALSAN = 'Asia/Choibalsan'
    ASIA_SLASH_COLOMBO = 'Asia/Colombo'
    ASIA_SLASH_DAMASCUS = 'Asia/Damascus'
    ASIA_SLASH_DHAKA = 'Asia/Dhaka'
    ASIA_SLASH_DILI = 'Asia/Dili'
    ASIA_SLASH_DUBAI = 'Asia/Dubai'
    ASIA_SLASH_DUSHANBE = 'Asia/Dushanbe'
    ASIA_SLASH_FAMAGUSTA = 'Asia/Famagusta'
    ASIA_SLASH_GAZA = 'Asia/Gaza'
    ASIA_SLASH_HEBRON = 'Asia/Hebron'
    ASIA_SLASH_HO_CHI_MINH = 'Asia/Ho_Chi_Minh'
    ASIA_SLASH_HONG_KONG = 'Asia/Hong_Kong'
    ASIA_SLASH_HOVD = 'Asia/Hovd'
    ASIA_SLASH_IRKUTSK = 'Asia/Irkutsk'
    ASIA_SLASH_JAKARTA = 'Asia/Jakarta'
    ASIA_SLASH_JAYAPURA = 'Asia/Jayapura'
    ASIA_SLASH_JERUSALEM = 'Asia/Jerusalem'
    ASIA_SLASH_KABUL = 'Asia/Kabul'
    ASIA_SLASH_KAMCHATKA = 'Asia/Kamchatka'
    ASIA_SLASH_KARACHI = 'Asia/Karachi'
    ASIA_SLASH_KATHMANDU = 'Asia/Kathmandu'
    ASIA_SLASH_KHANDYGA = 'Asia/Khandyga'
    ASIA_SLASH_KOLKATA = 'Asia/Kolkata'
    ASIA_SLASH_KRASNOYARSK = 'Asia/Krasnoyarsk'
    ASIA_SLASH_KUALA_LUMPUR = 'Asia/Kuala_Lumpur'
    ASIA_SLASH_KUCHING = 'Asia/Kuching'
    ASIA_SLASH_KUWAIT = 'Asia/Kuwait'
    ASIA_SLASH_MACAU = 'Asia/Macau'
    ASIA_SLASH_MAGADAN = 'Asia/Magadan'
    ASIA_SLASH_MAKASSAR = 'Asia/Makassar'
    ASIA_SLASH_MANILA = 'Asia/Manila'
    ASIA_SLASH_MUSCAT = 'Asia/Muscat'
    ASIA_SLASH_NICOSIA = 'Asia/Nicosia'
    ASIA_SLASH_NOVOKUZNETSK = 'Asia/Novokuznetsk'
    ASIA_SLASH_NOVOSIBIRSK = 'Asia/Novosibirsk'
    ASIA_SLASH_OMSK = 'Asia/Omsk'
    ASIA_SLASH_ORAL = 'Asia/Oral'
    ASIA_SLASH_PHNOM_PENH = 'Asia/Phnom_Penh'
    ASIA_SLASH_PONTIANAK = 'Asia/Pontianak'
    ASIA_SLASH_PYONGYANG = 'Asia/Pyongyang'
    ASIA_SLASH_QATAR = 'Asia/Qatar'
    ASIA_SLASH_QOSTANAY = 'Asia/Qostanay'
    ASIA_SLASH_QYZYLORDA = 'Asia/Qyzylorda'
    ASIA_SLASH_RIYADH = 'Asia/Riyadh'
    ASIA_SLASH_SAKHALIN = 'Asia/Sakhalin'
    ASIA_SLASH_SAMARKAND = 'Asia/Samarkand'
    ASIA_SLASH_SEOUL = 'Asia/Seoul'
    ASIA_SLASH_SHANGHAI = 'Asia/Shanghai'
    ASIA_SLASH_SINGAPORE = 'Asia/Singapore'
    ASIA_SLASH_SREDNEKOLYMSK = 'Asia/Srednekolymsk'
    ASIA_SLASH_TAIPEI = 'Asia/Taipei'
    ASIA_SLASH_TASHKENT = 'Asia/Tashkent'
    ASIA_SLASH_TBILISI = 'Asia/Tbilisi'
    ASIA_SLASH_TEHRAN = 'Asia/Tehran'
    ASIA_SLASH_THIMPHU = 'Asia/Thimphu'
    ASIA_SLASH_TOKYO = 'Asia/Tokyo'
    ASIA_SLASH_TOMSK = 'Asia/Tomsk'
    ASIA_SLASH_ULAANBAATAR = 'Asia/Ulaanbaatar'
    ASIA_SLASH_URUMQI = 'Asia/Urumqi'
    ASIA_SLASH_UST_MINUS_NERA = 'Asia/Ust-Nera'
    ASIA_SLASH_VIENTIANE = 'Asia/Vientiane'
    ASIA_SLASH_VLADIVOSTOK = 'Asia/Vladivostok'
    ASIA_SLASH_YAKUTSK = 'Asia/Yakutsk'
    ASIA_SLASH_YANGON = 'Asia/Yangon'
    ASIA_SLASH_YEKATERINBURG = 'Asia/Yekaterinburg'
    ASIA_SLASH_YEREVAN = 'Asia/Yerevan'
    ATLANTIC_SLASH_AZORES = 'Atlantic/Azores'
    ATLANTIC_SLASH_BERMUDA = 'Atlantic/Bermuda'
    ATLANTIC_SLASH_CANARY = 'Atlantic/Canary'
    ATLANTIC_SLASH_CAPE_VERDE = 'Atlantic/Cape_Verde'
    ATLANTIC_SLASH_FAROE = 'Atlantic/Faroe'
    ATLANTIC_SLASH_MADEIRA = 'Atlantic/Madeira'
    ATLANTIC_SLASH_REYKJAVIK = 'Atlantic/Reykjavik'
    ATLANTIC_SLASH_SOUTH_GEORGIA = 'Atlantic/South_Georgia'
    ATLANTIC_SLASH_ST_HELENA = 'Atlantic/St_Helena'
    ATLANTIC_SLASH_STANLEY = 'Atlantic/Stanley'
    AUSTRALIA_SLASH_ADELAIDE = 'Australia/Adelaide'
    AUSTRALIA_SLASH_BRISBANE = 'Australia/Brisbane'
    AUSTRALIA_SLASH_BROKEN_HILL = 'Australia/Broken_Hill'
    AUSTRALIA_SLASH_DARWIN = 'Australia/Darwin'
    AUSTRALIA_SLASH_EUCLA = 'Australia/Eucla'
    AUSTRALIA_SLASH_HOBART = 'Australia/Hobart'
    AUSTRALIA_SLASH_LINDEMAN = 'Australia/Lindeman'
    AUSTRALIA_SLASH_LORD_HOWE = 'Australia/Lord_Howe'
    AUSTRALIA_SLASH_MELBOURNE = 'Australia/Melbourne'
    AUSTRALIA_SLASH_PERTH = 'Australia/Perth'
    AUSTRALIA_SLASH_SYDNEY = 'Australia/Sydney'
    CANADA_SLASH_ATLANTIC = 'Canada/Atlantic'
    CANADA_SLASH_CENTRAL = 'Canada/Central'
    CANADA_SLASH_EASTERN = 'Canada/Eastern'
    CANADA_SLASH_MOUNTAIN = 'Canada/Mountain'
    CANADA_SLASH_NEWFOUNDLAND = 'Canada/Newfoundland'
    CANADA_SLASH_PACIFIC = 'Canada/Pacific'
    EUROPE_SLASH_AMSTERDAM = 'Europe/Amsterdam'
    EUROPE_SLASH_ANDORRA = 'Europe/Andorra'
    EUROPE_SLASH_ASTRAKHAN = 'Europe/Astrakhan'
    EUROPE_SLASH_ATHENS = 'Europe/Athens'
    EUROPE_SLASH_BELGRADE = 'Europe/Belgrade'
    EUROPE_SLASH_BERLIN = 'Europe/Berlin'
    EUROPE_SLASH_BRATISLAVA = 'Europe/Bratislava'
    EUROPE_SLASH_BRUSSELS = 'Europe/Brussels'
    EUROPE_SLASH_BUCHAREST = 'Europe/Bucharest'
    EUROPE_SLASH_BUDAPEST = 'Europe/Budapest'
    EUROPE_SLASH_BUSINGEN = 'Europe/Busingen'
    EUROPE_SLASH_CHISINAU = 'Europe/Chisinau'
    EUROPE_SLASH_COPENHAGEN = 'Europe/Copenhagen'
    EUROPE_SLASH_DUBLIN = 'Europe/Dublin'
    EUROPE_SLASH_GIBRALTAR = 'Europe/Gibraltar'
    EUROPE_SLASH_GUERNSEY = 'Europe/Guernsey'
    EUROPE_SLASH_HELSINKI = 'Europe/Helsinki'
    EUROPE_SLASH_ISLE_OF_MAN = 'Europe/Isle_of_Man'
    EUROPE_SLASH_ISTANBUL = 'Europe/Istanbul'
    EUROPE_SLASH_JERSEY = 'Europe/Jersey'
    EUROPE_SLASH_KALININGRAD = 'Europe/Kaliningrad'
    EUROPE_SLASH_KIROV = 'Europe/Kirov'
    EUROPE_SLASH_KYIV = 'Europe/Kyiv'
    EUROPE_SLASH_LISBON = 'Europe/Lisbon'
    EUROPE_SLASH_LJUBLJANA = 'Europe/Ljubljana'
    EUROPE_SLASH_LONDON = 'Europe/London'
    EUROPE_SLASH_LUXEMBOURG = 'Europe/Luxembourg'
    EUROPE_SLASH_MADRID = 'Europe/Madrid'
    EUROPE_SLASH_MALTA = 'Europe/Malta'
    EUROPE_SLASH_MARIEHAMN = 'Europe/Mariehamn'
    EUROPE_SLASH_MINSK = 'Europe/Minsk'
    EUROPE_SLASH_MONACO = 'Europe/Monaco'
    EUROPE_SLASH_MOSCOW = 'Europe/Moscow'
    EUROPE_SLASH_OSLO = 'Europe/Oslo'
    EUROPE_SLASH_PARIS = 'Europe/Paris'
    EUROPE_SLASH_PODGORICA = 'Europe/Podgorica'
    EUROPE_SLASH_PRAGUE = 'Europe/Prague'
    EUROPE_SLASH_RIGA = 'Europe/Riga'
    EUROPE_SLASH_ROME = 'Europe/Rome'
    EUROPE_SLASH_SAMARA = 'Europe/Samara'
    EUROPE_SLASH_SAN_MARINO = 'Europe/San_Marino'
    EUROPE_SLASH_SARAJEVO = 'Europe/Sarajevo'
    EUROPE_SLASH_SARATOV = 'Europe/Saratov'
    EUROPE_SLASH_SIMFEROPOL = 'Europe/Simferopol'
    EUROPE_SLASH_SKOPJE = 'Europe/Skopje'
    EUROPE_SLASH_SOFIA = 'Europe/Sofia'
    EUROPE_SLASH_STOCKHOLM = 'Europe/Stockholm'
    EUROPE_SLASH_TALLINN = 'Europe/Tallinn'
    EUROPE_SLASH_TIRANE = 'Europe/Tirane'
    EUROPE_SLASH_ULYANOVSK = 'Europe/Ulyanovsk'
    EUROPE_SLASH_VADUZ = 'Europe/Vaduz'
    EUROPE_SLASH_VATICAN = 'Europe/Vatican'
    EUROPE_SLASH_VIENNA = 'Europe/Vienna'
    EUROPE_SLASH_VILNIUS = 'Europe/Vilnius'
    EUROPE_SLASH_VOLGOGRAD = 'Europe/Volgograd'
    EUROPE_SLASH_WARSAW = 'Europe/Warsaw'
    EUROPE_SLASH_ZAGREB = 'Europe/Zagreb'
    EUROPE_SLASH_ZURICH = 'Europe/Zurich'
    GMT = 'GMT'
    INDIAN_SLASH_ANTANANARIVO = 'Indian/Antananarivo'
    INDIAN_SLASH_CHAGOS = 'Indian/Chagos'
    INDIAN_SLASH_CHRISTMAS = 'Indian/Christmas'
    INDIAN_SLASH_COCOS = 'Indian/Cocos'
    INDIAN_SLASH_COMORO = 'Indian/Comoro'
    INDIAN_SLASH_KERGUELEN = 'Indian/Kerguelen'
    INDIAN_SLASH_MAHE = 'Indian/Mahe'
    INDIAN_SLASH_MALDIVES = 'Indian/Maldives'
    INDIAN_SLASH_MAURITIUS = 'Indian/Mauritius'
    INDIAN_SLASH_MAYOTTE = 'Indian/Mayotte'
    INDIAN_SLASH_REUNION = 'Indian/Reunion'
    PACIFIC_SLASH_APIA = 'Pacific/Apia'
    PACIFIC_SLASH_AUCKLAND = 'Pacific/Auckland'
    PACIFIC_SLASH_BOUGAINVILLE = 'Pacific/Bougainville'
    PACIFIC_SLASH_CHATHAM = 'Pacific/Chatham'
    PACIFIC_SLASH_CHUUK = 'Pacific/Chuuk'
    PACIFIC_SLASH_EASTER = 'Pacific/Easter'
    PACIFIC_SLASH_EFATE = 'Pacific/Efate'
    PACIFIC_SLASH_FAKAOFO = 'Pacific/Fakaofo'
    PACIFIC_SLASH_FIJI = 'Pacific/Fiji'
    PACIFIC_SLASH_FUNAFUTI = 'Pacific/Funafuti'
    PACIFIC_SLASH_GALAPAGOS = 'Pacific/Galapagos'
    PACIFIC_SLASH_GAMBIER = 'Pacific/Gambier'
    PACIFIC_SLASH_GUADALCANAL = 'Pacific/Guadalcanal'
    PACIFIC_SLASH_GUAM = 'Pacific/Guam'
    PACIFIC_SLASH_HONOLULU = 'Pacific/Honolulu'
    PACIFIC_SLASH_KANTON = 'Pacific/Kanton'
    PACIFIC_SLASH_KIRITIMATI = 'Pacific/Kiritimati'
    PACIFIC_SLASH_KOSRAE = 'Pacific/Kosrae'
    PACIFIC_SLASH_KWAJALEIN = 'Pacific/Kwajalein'
    PACIFIC_SLASH_MAJURO = 'Pacific/Majuro'
    PACIFIC_SLASH_MARQUESAS = 'Pacific/Marquesas'
    PACIFIC_SLASH_MIDWAY = 'Pacific/Midway'
    PACIFIC_SLASH_NAURU = 'Pacific/Nauru'
    PACIFIC_SLASH_NIUE = 'Pacific/Niue'
    PACIFIC_SLASH_NORFOLK = 'Pacific/Norfolk'
    PACIFIC_SLASH_NOUMEA = 'Pacific/Noumea'
    PACIFIC_SLASH_PAGO_PAGO = 'Pacific/Pago_Pago'
    PACIFIC_SLASH_PALAU = 'Pacific/Palau'
    PACIFIC_SLASH_PITCAIRN = 'Pacific/Pitcairn'
    PACIFIC_SLASH_POHNPEI = 'Pacific/Pohnpei'
    PACIFIC_SLASH_PORT_MORESBY = 'Pacific/Port_Moresby'
    PACIFIC_SLASH_RAROTONGA = 'Pacific/Rarotonga'
    PACIFIC_SLASH_SAIPAN = 'Pacific/Saipan'
    PACIFIC_SLASH_TAHITI = 'Pacific/Tahiti'
    PACIFIC_SLASH_TARAWA = 'Pacific/Tarawa'
    PACIFIC_SLASH_TONGATAPU = 'Pacific/Tongatapu'
    PACIFIC_SLASH_WAKE = 'Pacific/Wake'
    PACIFIC_SLASH_WALLIS = 'Pacific/Wallis'
    US_SLASH_ALASKA = 'US/Alaska'
    US_SLASH_ARIZONA = 'US/Arizona'
    US_SLASH_CENTRAL = 'US/Central'
    US_SLASH_EASTERN = 'US/Eastern'
    US_SLASH_HAWAII = 'US/Hawaii'
    US_SLASH_MOUNTAIN = 'US/Mountain'
    US_SLASH_PACIFIC = 'US/Pacific'
    UTC = 'UTC'

    @classmethod
    def from_json(cls, json_str: str) -> TimezoneEnum: # noqa: F821
        """Create an instance of TimezoneEnum from a JSON string"""
        return TimezoneEnum(json.loads(json_str))


